==> haskell-network-multicast-0.3.2-263-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-BS7RkMakix0DgCimNeX0Xk
key:                  network-multicast-0.3.2-BS7RkMakix0DgCimNeX0Xk
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  e5dffed48d026f6171cf9ba3d2197cb0
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-multicast
hs-libraries:         HSnetwork-multicast-0.3.2-BS7RkMakix0DgCimNeX0Xk
depends:
    base-4.17.2.1 network-3.1.4.0-Clrm8B2IBAjIFHTKmEcInu
    network-bsd-2.8.1.0-9028IAH25n6HJjfJiBYkdy

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-multicast-0.3.2-264-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-75msBj4kWFO993VxdkerzW
key:                  network-multicast-0.3.2-75msBj4kWFO993VxdkerzW
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  405531e8d222550ad6a86ee5609650a3
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-multicast
hs-libraries:         HSnetwork-multicast-0.3.2-75msBj4kWFO993VxdkerzW
depends:
    base-4.17.2.1 network-3.1.4.0-ASj1hBk5tU17JSnFMFmeWy
    network-bsd-2.8.1.0-33ogtdL7a8DBibPic0vL2J

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
